GtdDioInterceptor class

Constructors

GtdDioInterceptor({bool? printOnSuccess, bool convertFormData = true})

Properties

convertFormData bool
final
hashCode int
The hash code for this object.
no setterinherited
printOnSuccess bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

logJson({String tag = "", dynamic json}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onError(DioException err, ErrorInterceptorHandler handler) → void
Called when an exception was occurred during the request.
onRequest(RequestOptions options, RequestInterceptorHandler handler) → void
Called when the request is about to be sent.
inherited
onResponse(Response response, ResponseInterceptorHandler handler) → void
Called when the response is about to be resolved.
prettyJson(dynamic json) String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited