GtdNetworkService class

Properties

cancelNetwork ↔ CancelToken
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
request GTDNetworkRequest
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute({Options? options, CancelToken? cancelToken, ProgressCallback? onSendProgress, ProgressCallback? onReceiveProgress}) Future<Response>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
uploadFile({required File file, required String fieldName, String? fileName, Map<String, dynamic>? extraData, CancelToken? cancelToken, ProgressCallback? onSendProgress, ProgressCallback? onReceiveProgress}) Future<Response>
Upload a single file to the server
uploadFiles({CancelToken? cancelToken, ProgressCallback? onSendProgress, ProgressCallback? onReceiveProgress}) Future<Response>
Upload files using multipart form data

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

shared GtdNetworkService
final