GTDNetworkRequest class
Constructors
Properties
- connectTimeout ↔ int
-
getter/setter pair
- data → dynamic
-
final
- enpoint → GtdEndpoint
-
final
-
files
↔ Map<
String, dynamic> ? -
Key-value pairs for multipart files, where key is the form field name
and value is either a File, List
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
↔ Map<
String, String> ? -
getter/setter pair
-
queryParams
↔ Map<
String, dynamic> ? -
getter/setter pair
- receiveTimeout ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ GtdMethod
-
getter/setter pair
Methods
-
buildUri(
) → Uri -
createFormData(
) → Future< FormData> - Creates a FormData object from the request data and files
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited